@@ -78,6 +78,7 @@ class PortInfo(CommonInfo):
         self.mac_address = None
         self.network = None
         self.chain_hops = dict()
+        self.admin_state_up = False
 
     def __eq__(self, other):
         return (isinstance(other, self.__class__) and
@@ -104,7 +105,7 @@ class PortInfo(CommonInfo):
             self.chain_hops.update(chain_hop)
 
     def __repr__(self):
-        return "PortInfo: %s" % self.id
+        return "PortInfo(%s,%s)" % (self.id, self.admin_state_up)
 
 
 GatewayInfo = namedtuple('GatewayInfo', ['mac', 'ip'])
@@ -124,7 +125,8 @@ class NetworkInfo(CommonInfo):
         self.gateway_info = gateway_info
 
     def __repr__(self):
-        return "NetInfo: %s" % self.id
+        return "NetInfo: %s (segmentation id:%s, gw:%s), " % (
+            self.id, self.segmentation_id, self.gateway_info)
 
 
 class BaseInfoManager(object):
