@@ -18,6 +18,7 @@
 import abc
 import collections
 import copy
+import itertools
 import re
 import socket
 import threading
@@ -442,6 +443,9 @@ class VPNInstance(tracker_worker.TrackerWorker,
         return (len(self.localport_2_endpoints) == 1 and
                 len(six.next(six.itervalues(self.localport_2_endpoints))) == 1)
 
+    def all_endpoints(self):
+        return itertools.chain(*self.localport_2_endpoints.values())
+
     @log_decorator.log
     def update_route_targets(self, new_import_rts, new_export_rts):
         added_import_rt = set(new_import_rts) - set(self.import_rts)
